@@ -44,11 +44,11 @@ def fsize( ) :
     #os.path.getsize( fp )
 
 def fsize_limited( ) :
-    fs=fsize()
+    fs = fsize( )
     if( fs > 20971520 ) :
-        s_log.write(fs)
+        s_log.write( "ERROR fsize_limited " + str( fs ) )
         return( True )
-    return(False)
+    return( False )
 
 def db_stash( ) :
 
