@@ -75,17 +75,17 @@ def check_connectivity( ) :
 
     ################################################################
 
-    if( s_config.get_key( "endpoint/skipnetworkcheck1" ) != "yes" ) : 
+    #if( s_config.get_key( "endpoint/skipnetworkcheck1" ) != "yes" ) : 
 
-        try :
+    #    try :
 
-            host = socket.gethostbyname( endpoint_parseurl.hostname ) 
-            s = socket.create_connection( ( host , endpoint_url_port ) , 10 )
-            s.close( )
+    #        host = socket.gethostbyname( endpoint_parseurl.hostname ) 
+    #        s = socket.create_connection( ( host , endpoint_url_port ) , 10 )
+    #        s.close( )
 
-        except Exception as e :
-            s_log.write( "False check_connectivity 1" )
-            flag_networkok = False
+    #    except Exception as e :
+    #        s_log.write( "False check_connectivity 1" )
+    #        flag_networkok = False
 
     ################################################################
 
@@ -171,7 +171,7 @@ def job_request( params = { } ) :
     headers = { "X-Omni-Action": "job_request" }
     headers[ "X-Omni-Params" ] = s_util.json_encode( params )
     if( len( headers[ "X-Omni-Params" ] ) > 4096 ) :
-        s_log.write( "ERROR Params TO BIG?? > 4096 bytes" )
+        s_log.write( "ERROR Params TO BIG?? > 4096 bytes... " + str len( headers[ "X-Omni-Params" ] ) )
         return( False )
 
 
@@ -497,9 +497,9 @@ def get_request_response( request_headers = { }  , payload = "" ) :
     if ( response.status_code == 200 ) :
         #X-Sapi-Tokensession
         if( "X-Sapi-Tokensession" in response.headers ) :
-            token_session=response.headers[ "X-Sapi-Tokensession" ]
+            token_session = response.headers[ "X-Sapi-Tokensession" ]
             s_config.set_key_fsoneshot( "token_session" , token_session )
-            #s_log.write(token_session)
+            #s_log.write( token_session )
         return( response )
 
     #####################################################################
